@@ -10,7 +10,7 @@ use strict;
 use Modern::Perl;
 
 package Dist::Zilla::Plugin::Subversion::Tag;
-our $VERSION = '1.100880';
+our $VERSION = '1.100890';
 
 # ABSTRACT: tags a distribution in Subversion
 
@@ -74,7 +74,7 @@ Dist::Zilla::Plugin::Subversion::Tag - tags a distribution in Subversion
 
 =head1 VERSION
 
-version 1.100880
+version 1.100890
 
 =head1 DESCRIPTION
 
@@ -102,7 +102,7 @@ Copies the working copy to a tag named after the distribution and its version.
 
 =head1 AUTHOR
 
-  Mark Gardner <gardnerm@gsicommerce.com>
+  Mark Gardner <mjgardner@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
